@@ -195,9 +195,9 @@ def get_cmd_shell_repr(cmd: str, *args: str, env: Optional[Dict[str, str]]) -> s
     return " ".join(env_repr + [cmd] + list(map(shell_escape, args)))
 
 
-def warn(msg: str, apply_fmt: bool = True) -> None:
+def warn(msg: str, apply_fmt: bool = True, end: str = '\n') -> None:
     if msg not in displayed_warnings:
-        print(colored("Warn: ", AnsiEscapeCodes.RED) + (fmt(msg) if apply_fmt else msg), file=sys.stderr)
+        print(colored("Warn: ", AnsiEscapeCodes.ORANGE) + (fmt(msg) if apply_fmt else msg), file=sys.stderr, end=end)
         displayed_warnings.add(msg)
 
 
